@@ -65,13 +65,13 @@ namespace Flickr
     RequestedSize _requestedSize;
 
     int doCalculateNextIndex(bool randomMode, int currentIndex, int pages) const;
-    QUrl doPrepareInit(QHttpRequestHeader &header);
-    QUrl doPrepareSearch(QHttpRequestHeader &header, bool &shouldEncode);
+    QUrl doPrepareInit(HttpEngine::Operation &op);
+    QUrl doPrepareSearch(HttpEngine::Operation &op);
     bool doProcessSearchResult(const QByteArray &response, int &newPagesCount);
-    QUrl prepareSizeRequest(QHttpRequestHeader &header);
+    QUrl prepareSizeRequest(HttpEngine::Operation &op);
     QSize doProcessSizeRequestResult(const QByteArray &response);
-    QUrl prepareDownload(QHttpRequestHeader &header);
-    QUrl prepareInfoCollect(QHttpRequestHeader &header);
+    QUrl prepareDownload(HttpEngine::Operation &op);
+    QUrl prepareInfoCollect(HttpEngine::Operation &op);
     PhotoInfo doProcessInfoCollectResult(const QByteArray &response);
 
     void doLoadSettings(QSettings &settings);
