@@ -25,7 +25,7 @@
 #include <QtNetwork>
 
 #include "ui_http.h"
-#include "httpex.h"
+#include "networkmanager.h"
 #include "engine.h"
 #include "xtengine.h"
 
@@ -34,6 +34,8 @@
 
 namespace HttpEngine
 {
+  enum Operation { Get, Post };
+
   class Item : public XtEngine::Item
   {
     Q_OBJECT
@@ -43,6 +45,7 @@ namespace HttpEngine
 
     int _pageIndex;
     int _pages;
+    int _consecutiveSearchesFailed;
 
     void loadState(QSettings &settings, const QString &group);
     void saveState(QSettings &settings, const QString &engineName, int id) const;
@@ -50,10 +53,10 @@ namespace HttpEngine
     void saveSettings(QSettings &settings, const QString &engineName, int id) const;
 
   protected:
-    virtual QUrl doPrepareInit(QHttpRequestHeader &header) = 0;
+    virtual QUrl doPrepareInit(Operation &op) = 0;
     virtual void doProcessInitResult(const QByteArray & /* response */) { }
     virtual int doCalculateNextIndex(bool randomMode, int currentIndex, int pages) const = 0;
-    virtual QUrl doPrepareSearch(QHttpRequestHeader &header, bool &shouldEncode) = 0;
+    virtual QUrl doPrepareSearch(Operation &op) = 0;
     virtual bool doProcessSearchResult(const QByteArray &response, int &newPagesCount) = 0;
     virtual QSize doProcessSizeRequestResult(const QByteArray &response) = 0;
     virtual void doProcessDownloadResult(const QFileInfo & /* fileInfo */) { }
@@ -71,15 +74,15 @@ namespace HttpEngine
 
     void resetPages() { _pageIndex = _pages = 0; }
 
-    QUrl prepareInit(QHttpRequestHeader &header);
+    QUrl prepareInit(Operation &op);
     void processInitResult(const QByteArray &response);
-    QUrl prepareSearch(bool randomMode, QHttpRequestHeader &header, bool &shouldEncode);
+    QUrl prepareSearch(bool randomMode, Operation &op);
     bool processSearchResult(const QByteArray &response);
-    virtual QUrl prepareSizeRequest(QHttpRequestHeader &header) = 0;
+    virtual QUrl prepareSizeRequest(Operation &op) = 0;
     QSize processSizeRequestResult(const QByteArray &response);
-    virtual QUrl prepareDownload(QHttpRequestHeader &header) = 0;
+    virtual QUrl prepareDownload(Operation &op) = 0;
     void processDownloadResult(const QFileInfo &fileInfo, bool belowThreshold);
-    virtual QUrl prepareInfoCollect(QHttpRequestHeader &header) = 0;
+    virtual QUrl prepareInfoCollect(Operation &op) = 0;
     PhotoInfo processInfoCollectResult(const QByteArray &response);
 
     void setPhotosPath(const QString &photosPath) { _photosPath = photosPath; }
@@ -98,22 +101,23 @@ namespace HttpEngine
     bool canceling;
     bool cancelSignaled;
     qint64 _diskSpaceThreshold;
-    HttpEx::Interface *initHttp;
-    HttpEx::Interface *searchHttp;
-    HttpEx::Interface *sizeRequestHttp;
-    HttpEx::Interface *downloadHttp;
-    HttpEx::Interface *infoCollectHttp;
-    QFile httpFile;
+    Network::Manager *initHttp;
+    Network::Manager *searchHttp;
+    Network::Manager *sizeRequestHttp;
+    Network::Manager *downloadHttp;
+    Network::Manager *infoCollectHttp;
+    QPointer< Network::Reply > currentReply;
+    QFileInfo httpFile;
     QNetworkProxy httpProxy;
 
     QNetworkProxy guessProxy(const QUrl &url);
 
   private slots:
-    void httpInitDone(bool error);
-    void httpSearchDone(bool error);
-    void httpSizeRequestDone(bool error);
-    void httpDownloadDone(bool error);
-    void httpInfoCollectDone(bool error);
+    void httpInitDone(bool ok, const QByteArray &data);
+    void httpSearchDone(bool ok, const QByteArray &data);
+    void httpSizeRequestDone(bool ok, const QByteArray &data);
+    void httpDownloadDone(bool ok, const QByteArray &data);
+    void httpInfoCollectDone(bool ok, const QByteArray &data);
 
   public:
     Core(const QString &tempStorageDir, QObject *parent = 0);
