@@ -57,14 +57,14 @@ namespace Photobucket
     QByteArray hmacSha1(const QByteArray &data, const QByteArray &key);
 
     int doCalculateNextIndex(bool randomMode, int currentIndex, int pages) const;
-    QUrl doPrepareInit(QHttpRequestHeader &header);
+    QUrl doPrepareInit(HttpEngine::Operation &op);
     void doProcessInitResult(const QByteArray &response);
-    QUrl doPrepareSearch(QHttpRequestHeader &header, bool &shouldEncode);
+    QUrl doPrepareSearch(HttpEngine::Operation &op);
     bool doProcessSearchResult(const QByteArray &response, int &newPagesCount);
-    QUrl prepareSizeRequest(QHttpRequestHeader &header);
+    QUrl prepareSizeRequest(HttpEngine::Operation &op);
     QSize doProcessSizeRequestResult(const QByteArray &response);
-    QUrl prepareDownload(QHttpRequestHeader &header);
-    QUrl prepareInfoCollect(QHttpRequestHeader &header);
+    QUrl prepareDownload(HttpEngine::Operation &op);
+    QUrl prepareInfoCollect(HttpEngine::Operation &op);
     PhotoInfo doProcessInfoCollectResult(const QByteArray &response);
 
     void doLoadSettings(QSettings &settings);
