@@ -95,10 +95,6 @@
         <source>Czech</source>
         <translation>cseh</translation>
     </message>
-    <message>
-        <source>Chinese</source>
-        <translation>kínai</translation>
-    </message>
     <message>
         <source>Polish</source>
         <translation>lengyel</translation>
@@ -131,6 +127,14 @@
         <source>Turkish</source>
         <translation>Török</translation>
     </message>
+    <message>
+        <source>Chinese (Simplified)</source>
+        <translation>Kínai (egyszerűsített)</translation>
+    </message>
+    <message>
+        <source>Chinese (Traditional)</source>
+        <translation>Kínai (hagyományos)</translation>
+    </message>
 </context>
 <context>
     <name>Bing::DialogWidget</name>
@@ -321,10 +325,6 @@
 </context>
 <context>
     <name>Files::SettingsWidget</name>
-    <message>
-        <source>Files</source>
-        <translation>Fájlok</translation>
-    </message>
     <message>
         <source>Select a photo</source>
         <translation>Kép választása</translation>
@@ -632,13 +632,6 @@
         <translation>Aktív</translation>
     </message>
 </context>
-<context>
-    <name>Folders::SettingsWidget</name>
-    <message>
-        <source>Folders</source>
-        <translation>Mappák</translation>
-    </message>
-</context>
 <context>
     <name>FoldersSettingsWidget</name>
     <message>
@@ -1792,6 +1785,10 @@ Do you want to delete it anyway?</source>
         <source>Are you sure?</source>
         <translation>Biztos benne?</translation>
     </message>
+    <message>
+        <source>Engines</source>
+        <translation>Modulok</translation>
+    </message>
 </context>
 <context>
     <name>SmugMug::DialogWidget</name>
@@ -1829,10 +1826,6 @@ Do you want to delete it anyway?</source>
         <source>Loading Flickr module ...</source>
         <translation>Flickr modul betöltése ...</translation>
     </message>
-    <message>
-        <source>Loading Yahoo! module ...</source>
-        <translation>Yahoo! modul betöltése ...</translation>
-    </message>
     <message>
         <source>Loading Panoramio module ...</source>
         <translation>Panoramio modul betöltése ...</translation>
@@ -2101,10 +2094,6 @@ Do you want to delete it anyway?</source>
         <source>Polish</source>
         <translation>lengyel</translation>
     </message>
-    <message>
-        <source>Chinese</source>
-        <translation>kínai</translation>
-    </message>
     <message>
         <source>Catalan</source>
         <translation>katalán</translation>
@@ -2165,6 +2154,14 @@ Do you want to delete it anyway?</source>
         <source>Turkish</source>
         <translation>Török</translation>
     </message>
+    <message>
+        <source>Chinese (Simplified)</source>
+        <translation>Kínai (egyszerűsített)</translation>
+    </message>
+    <message>
+        <source>Chinese (Traditional)</source>
+        <translation>Kínai (hagyományos)</translation>
+    </message>
 </context>
 <context>
     <name>Yahoo::DialogWidget</name>
