@@ -27,10 +27,7 @@ TRANSLATOR Bing::DialogWidget
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <QtCore>
-#include <QtGui>
 #include <QtXml>
-#include <QtNetwork>
 
 #include "httpengine.h"
 #include "bing.h"
@@ -88,7 +85,7 @@ int Item::doCalculateNextIndex(bool randomMode, int currentIndex, int pages) con
   return (pages)? (currentIndex + ((randomMode)? (qrand() % 5) + 1 : 1) % pages) : 0;
 }
 
-QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
+QUrl Item::doPrepareInit(HttpEngine::Operation & /* op */)
 {
   photoTitle.clear();
   photoDescription.clear();
@@ -100,7 +97,7 @@ QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
   return QUrl();
 }
 
-QUrl Item::doPrepareSearch(QHttpRequestHeader & /* header */, bool & /* shouldEncode */)
+QUrl Item::doPrepareSearch(HttpEngine::Operation & /* op */)
 {
   QUrl url("http://api.bing.net/xml.aspx");
 
@@ -110,7 +107,7 @@ QUrl Item::doPrepareSearch(QHttpRequestHeader & /* header */, bool & /* shouldEn
     switch (_tagsCondition)
     {
       case And:
-        url.addQueryItem("Query",QString("\"") + _tags.join("+") + "\"");
+        url.addQueryItem("Query",_tags.join("+"));
         break;
 
       case Or:
@@ -214,7 +211,7 @@ bool Item::doProcessSearchResult(const QByteArray &response, int &newPagesCount)
   return (!respError && _photoUrl.isValid() && !_lastPhotoUrls.contains(_photoUrl));
 }
 
-QUrl Item::prepareSizeRequest(QHttpRequestHeader & /* header */)
+QUrl Item::prepareSizeRequest(HttpEngine::Operation & /* op */)
 {
   return QUrl("/");
 }
@@ -224,12 +221,12 @@ QSize Item::doProcessSizeRequestResult(const QByteArray & /* response */)
   return photoSize;
 }
 
-QUrl Item::prepareDownload(QHttpRequestHeader & /* header */)
+QUrl Item::prepareDownload(HttpEngine::Operation & /* op */)
 {
   return _photoUrl;
 }
 
-QUrl Item::prepareInfoCollect(QHttpRequestHeader & /* header */)
+QUrl Item::prepareInfoCollect(HttpEngine::Operation & /* op */)
 {
   _lastPhotoUrls.insert(_photoUrl);
   return QUrl("/");
