@@ -23,8 +23,6 @@ TRANSLATOR Exif::InfoDialog
 
 #include <string.h>
 #include <QtDebug>
-#include <QtCore>
-#include <QtGui>
 
 #ifdef EXIF
   #include <libexif/exif-byte-order.h>
