@@ -36,9 +36,6 @@ TRANSLATOR Folders::SettingsWidget
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <QtCore>
-#include <QtGui>
-
 #include "exif.h"
 #include "utils.h"
 #include "engine.h"
@@ -124,7 +121,8 @@ void LocalItem::buildFileList()
 {
   QFileInfo fileInfo;
   QDirIterator scan(absolutePath(),
-                    (isRecursion())? QDirIterator::Subdirectories : QDirIterator::NoIteratorFlags);
+                    ((isRecursion())? QDirIterator::Subdirectories : QDirIterator::NoIteratorFlags) |
+                    QDirIterator::FollowSymlinks);
 
   qDebug() << metaObject()->className() << "::buildFileList()";
 
@@ -678,7 +676,7 @@ void SettingsWidget::dropEvent(QDropEvent *event)
 
   while (url.hasNext())
   {
-    item = qobject_cast<LocalItem *> (core()->newItem(false));
+    item = qobject_cast<LocalItem *> (core()->newItem(QVariant(false)));
     item->setPath(url.next().toLocalFile());
 
     *qobject_cast<Core *> (core()) << item;
