@@ -31,12 +31,8 @@ TRANSLATOR History::Dialog
  */
 
 #include <QtDebug>
-#include <QtCore>
-#include <QtGui>
-#include <QtSql>
-#include <QtNetwork>
 
-#include "httpex.h"
+#include "networkmanager.h"
 #include "defs.h"
 #include "exif.h"
 #include "engine.h"
@@ -362,6 +358,8 @@ Dialog::Dialog(const QSqlDatabase &db, const QString &tempStorageDir, QWidget *p
   photosView->setDragDropMode(QAbstractItemView::NoDragDrop);
   photosView->setAlternatingRowColors(true);
   photosView->setResizeMode(QListView::Adjust);
+  photosView->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
+  photosView->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);
 
   hintLabel->setText(tr("Right-click on items to show options"));
   hintLabel->setAlignment(Qt::AlignCenter | Qt::AlignVCenter);
@@ -451,7 +449,6 @@ void Dialog::execSavePhoto()
 {
   int row = photosSelectionModel->currentIndex().row();
   QUrl url = photosQueryModel->record(row).value("url").toString();
-  QString urlStr, fileName;
 
 #ifdef Q_WS_X11
   fileName = QFileDialog::getSaveFileName(0,tr("Save photo"),
@@ -467,11 +464,6 @@ void Dialog::execSavePhoto()
   if (!fileName.isEmpty())
   {
     httpProgressDialog = newHttpProgressDialog(this);
-    connect(httpProgressDialog,SIGNAL(canceled()),http,SLOT(abort()));
-    connect(http,SIGNAL(done(bool)),httpProgressDialog,SLOT(reset()));
-
-    file = new QFile(fileName);
-    file->open(QIODevice::WriteOnly);
 
     request = reqFile;
     if (!httpProxy.hostName().compare("0.0.0.0"))
@@ -479,10 +471,13 @@ void Dialog::execSavePhoto()
     else
       http->setProxy(httpProxy);
 
-    urlStr = url.toEncoded();
+    Network::Reply *reply = http->get(url,fileName);
+
+    connect(httpProgressDialog,SIGNAL(canceled()),reply,SLOT(abort()));
+    connect(reply,SIGNAL(finished(bool,const QByteArray &)),httpProgressDialog,SLOT(reset()));
+    connect(reply,SIGNAL(finished(bool,const QByteArray &)),this,SLOT(httpDone(bool,const QByteArray &)));
+    connect(reply,SIGNAL(progress(qint64,qint64)),this,SLOT(httpDownloading(qint64,qint64)));
 
-    http->setHost(url.host());
-    http->get(urlStr.remove(0,urlStr.indexOf(url.encodedPath())),file);
     httpProgressDialog->show();
   }
 }
@@ -491,14 +486,10 @@ void Dialog::execSetAsBackground()
 {
   int row = photosSelectionModel->currentIndex().row();
   QUrl url = photosQueryModel->record(row).value("url").toString();
-  QString urlStr;
 
   httpProgressDialog = newHttpProgressDialog(this);
-  connect(httpProgressDialog,SIGNAL(canceled()),http,SLOT(abort()));
-  connect(http,SIGNAL(done(bool)),httpProgressDialog,SLOT(reset()));
 
-  file = new QFile(_tempStorageDir + "/" + QFileInfo(url.path()).fileName());
-  file->open(QIODevice::WriteOnly);
+  fileName = _tempStorageDir + "/" + QFileInfo(url.path()).fileName();
 
   request = reqWallpaper;
   if (!httpProxy.hostName().compare("0.0.0.0"))
@@ -506,10 +497,13 @@ void Dialog::execSetAsBackground()
   else
     http->setProxy(httpProxy);
 
-  urlStr = url.toEncoded();
+  Network::Reply *reply = http->get(url,fileName);
+
+  connect(httpProgressDialog,SIGNAL(canceled()),reply,SLOT(abort()));
+  connect(reply,SIGNAL(finished(bool,const QByteArray &)),httpProgressDialog,SLOT(reset()));
+  connect(reply,SIGNAL(finished(bool,const QByteArray &)),this,SLOT(httpDone(bool,const QByteArray &)));
+  connect(reply,SIGNAL(progress(qint64,qint64)),this,SLOT(httpDownloading(qint64,qint64)));
 
-  http->setHost(url.host());
-  http->get(urlStr.remove(0,urlStr.indexOf(url.encodedPath())),file);
   httpProgressDialog->show();
 }
 
@@ -532,14 +526,9 @@ void Dialog::execViewPhoto()
 {
   int row = photosSelectionModel->currentIndex().row();
   QUrl url = photosQueryModel->record(row).value("url").toString();
-  QString urlStr;
 
   httpProgressDialog = newHttpProgressDialog(this);
-  connect(httpProgressDialog,SIGNAL(canceled()),http,SLOT(abort()));
-  connect(http,SIGNAL(done(bool)),httpProgressDialog,SLOT(reset()));
-
-  file = new QFile(_tempStorageDir + "/" + QFileInfo(url.path()).fileName());
-  file->open(QIODevice::WriteOnly);
+  fileName = _tempStorageDir + "/" + QFileInfo(url.path()).fileName();
 
   request = reqView;
   if (!httpProxy.hostName().compare("0.0.0.0"))
@@ -547,10 +536,13 @@ void Dialog::execViewPhoto()
   else
     http->setProxy(httpProxy);
 
-  urlStr = url.toEncoded();
+  Network::Reply *reply = http->get(url,fileName);
+
+  connect(httpProgressDialog,SIGNAL(canceled()),reply,SLOT(abort()));
+  connect(reply,SIGNAL(finished(bool,const QByteArray &)),httpProgressDialog,SLOT(reset()));
+  connect(reply,SIGNAL(finished(bool,const QByteArray &)),this,SLOT(httpDone(bool,const QByteArray &)));
+  connect(reply,SIGNAL(progress(qint64,qint64)),this,SLOT(httpDownloading(qint64,qint64)));
 
-  http->setHost(url.host());
-  http->get(urlStr.remove(0,urlStr.indexOf(url.encodedPath())),file);
   httpProgressDialog->show();
 }
 
@@ -565,7 +557,7 @@ void Dialog::execExploreImageSource()
   }
 }
 
-void Dialog::httpDownloading(int /* currentTry */, int done, int total)
+void Dialog::httpDownloading(qint64 done, qint64 total)
 {
   if (!httpProgressDialog->wasCanceled())
   {
@@ -574,7 +566,7 @@ void Dialog::httpDownloading(int /* currentTry */, int done, int total)
   }
 }
 
-void Dialog::httpDone(bool error)
+void Dialog::httpDone(bool ok, const QByteArray & /* data */)
 {
   Viewer *viewer;
   PhotoInfo info;
@@ -584,14 +576,12 @@ void Dialog::httpDone(bool error)
   httpProgressDialog->reset();
   row = photosSelectionModel->currentIndex().row();
 
-  if (!error)
+  if (ok)
   {
-    file->close();
-
     switch (request)
     {
       case reqWallpaper:
-        emit photoDownloaded(true,QFileInfo(file->fileName()));
+        emit photoDownloaded(true,QFileInfo(fileName));
 
         info.owner = photosQueryModel->record(row).value("owner").toString();
         info.title = photosQueryModel->record(row).value("title").toString();
@@ -609,7 +599,7 @@ void Dialog::httpDone(bool error)
       case reqView:
         viewer = new Viewer(this);
 
-        viewer->setPixmap(QPixmap(file->fileName()));
+        viewer->setPixmap(QPixmap(fileName));
         viewer->setWindowTitle(photosQueryModel->record(row).value("title").toString());
 
         viewer->exec();
@@ -625,8 +615,7 @@ void Dialog::httpDone(bool error)
   httpProgressDialog->deleteLater();
   httpProgressDialog = 0;
 
-  delete file;
-  file = 0;
+  sender()->deleteLater();
 }
 
 void Dialog::initializeModelsAndViews()
@@ -717,12 +706,6 @@ QNetworkProxy Dialog::guessProxy(const QUrl &url)
 
 void Dialog::initHttp()
 {
-  HttpEx::Interface *retry;
-
-  file = 0;
   httpProgressDialog = 0;
-  retry = new HttpEx::Retry(new HttpEx::Log(new HttpEx::Base(new HttpEx::Core(new QHttp(this),this))));
-  http = new HttpEx::Timeout(retry);
-  connect(qobject_cast<HttpEx::Retry *> (retry),SIGNAL(completed(bool, const QByteArray &)),this,SLOT(httpDone(bool)));
-  connect(qobject_cast<HttpEx::Retry *> (retry),SIGNAL(progress(int,int,int)),this,SLOT(httpDownloading(int,int,int)));
+  http = new Network::Manager(this);
 }
