@@ -27,9 +27,6 @@ TRANSLATOR Ipernity::DialogWidget
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <QtCore>
-#include <QtGui>
-#include <QtNetwork>
 #include <QtXml>
 
 #include "httpengine.h"
@@ -77,7 +74,7 @@ int Item::doCalculateNextIndex(bool randomMode, int currentIndex, int pages) con
   return (pages)? (currentIndex + ((randomMode)? (qrand() % 5) + 1 : 1)) % pages : 1;
 }
 
-QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
+QUrl Item::doPrepareInit(HttpEngine::Operation & /* op */)
 {
   _photoId.clear();
   _photoUrl.clear();
@@ -91,7 +88,7 @@ QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
   return QUrl();
 }
 
-QUrl Item::doPrepareSearch(QHttpRequestHeader & /* header */, bool & /* shouldEncode */)
+QUrl Item::doPrepareSearch(HttpEngine::Operation & /* op */)
 {
   QString searchItem;
   QUrl url("http://api.ipernity.com/api/doc.search/xml");
@@ -142,13 +139,13 @@ bool Item::doProcessSearchResult(const QByteArray &response, int &newPagesCount)
   return (!_photoId.isEmpty() && !_lastPhotoIds.contains(_photoId));
 }
 
-QUrl Item::prepareSizeRequest(QHttpRequestHeader & /* header */)
+QUrl Item::prepareSizeRequest(HttpEngine::Operation & /* op */)
 {
   QUrl url("http://api.ipernity.com/api/doc.get/xml");
 
   url.addQueryItem("api_key",IPERNITY_API_KEY);
   url.addQueryItem("doc_id",_photoId);
-  url.addQueryItem("extra",QUrl::toPercentEncoding("notes,geo",QByteArray()," ,"));
+  url.addQueryItem("extra","notes,geo");
 
   return url;
 }
@@ -193,12 +190,12 @@ QSize Item::doProcessSizeRequestResult(const QByteArray &response)
   return photoSize;
 }
 
-QUrl Item::prepareDownload(QHttpRequestHeader & /* header */)
+QUrl Item::prepareDownload(HttpEngine::Operation & /* op */)
 {
   return _photoUrl;
 }
 
-QUrl Item::prepareInfoCollect(QHttpRequestHeader & /* header */)
+QUrl Item::prepareInfoCollect(HttpEngine::Operation & /* op */)
 {
   _lastPhotoIds.insert(_photoId);
   return QUrl("/");
