@@ -27,10 +27,7 @@ TRANSLATOR Panoramio::DialogWidget
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <QtCore>
-#include <QtGui>
-#include <QtNetwork>
-
+#include "json.h"
 #include "gui.h"
 #include "httpengine.h"
 #include "panoramio.h"
@@ -60,7 +57,7 @@ int Item::doCalculateNextIndex(bool randomMode, int currentIndex, int pages) con
   return (pages)? (currentIndex + ((randomMode)? (qrand() % 5) + 1 : 1)) % pages : 1;
 }
 
-QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
+QUrl Item::doPrepareInit(HttpEngine::Operation & /* op */)
 {
   _photoId.clear();
   photoOwner.clear();
@@ -73,7 +70,7 @@ QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
   return QUrl();
 }
 
-QUrl Item::doPrepareSearch(QHttpRequestHeader & /* header */, bool & /* shouldEncode */)
+QUrl Item::doPrepareSearch(HttpEngine::Operation & /* op */)
 {
   QUrl url("http://www.panoramio.com/map/get_panoramas.php");
 
@@ -125,7 +122,7 @@ bool Item::doProcessSearchResult(const QByteArray &response, int &newPagesCount)
 
     array = dynamic_cast<JSON::Array *> (object->value("photos"));
 
-    if (!array)
+    if (!array || !array->size())
     {
       qDebug() << metaObject()->className() << ": cannot find photos array";
       return false;
@@ -198,7 +195,7 @@ bool Item::doProcessSearchResult(const QByteArray &response, int &newPagesCount)
   return (!_photoId.isEmpty() && !_lastPhotoIds.contains(_photoId));
 }
 
-QUrl Item::prepareSizeRequest(QHttpRequestHeader & /* header */)
+QUrl Item::prepareSizeRequest(HttpEngine::Operation & /* op */)
 {
   return QUrl("/");
 }
@@ -208,21 +205,15 @@ QSize Item::doProcessSizeRequestResult(const QByteArray & /* response */)
   return photoSize;
 }
 
-QUrl Item::prepareDownload(QHttpRequestHeader &header)
+QUrl Item::prepareDownload(HttpEngine::Operation & /* op */)
 {
   if (_requestedSize == Original)
-  {
-    header.setRequest("GET","/photos/original/" + _photoId + ".jpg");
-    header.setValue("Host","static.panoramio.com");
-    header.setValue("Referer","http://www.panoramio.com/photo/" + _photoId);
-
     return QUrl("http://static.panoramio.com/photos/original/" + _photoId + ".jpg");
-  }
   else
     return _photoUrl;
 }
 
-QUrl Item::prepareInfoCollect(QHttpRequestHeader & /* header */)
+QUrl Item::prepareInfoCollect(HttpEngine::Operation & /* op */)
 {
   _lastPhotoIds.insert(_photoId);
   return QUrl("/");
