@@ -27,9 +27,6 @@ TRANSLATOR Photobucket::DialogWidget
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <QtCore>
-#include <QtGui>
-#include <QtNetwork>
 #include <QtXml>
 
 #include "httpengine.h"
@@ -93,7 +90,7 @@ int Item::doCalculateNextIndex(bool randomMode, int currentIndex, int pages) con
   return (pages)? (currentIndex + ((randomMode)? (qrand() % 5) + 1 : 1)) % pages : 1;
 }
 
-QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
+QUrl Item::doPrepareInit(HttpEngine::Operation & /* op */)
 {
   pbTimestamp = 0;
   _photoUrl.clear();
@@ -110,7 +107,7 @@ void Item::doProcessInitResult(const QByteArray &response)
   pbTimestamp = response.toInt();
 }
 
-QUrl Item::doPrepareSearch(QHttpRequestHeader & /* header */, bool &shouldEncode)
+QUrl Item::doPrepareSearch(HttpEngine::Operation & /* op */)
 {
   if (!pbTimestamp)
     return QUrl();
@@ -144,8 +141,7 @@ QUrl Item::doPrepareSearch(QHttpRequestHeader & /* header */, bool &shouldEncode
   signature = hmacSha1(base.join("&").toAscii(),QByteArray(PHOTOBUCKET_SECRET_KEY) + "&");
   params.insert(2,QString("oauth_signature=") + QUrl::toPercentEncoding(signature.toBase64()));
 
-  shouldEncode = false;
-  return QUrl(url.toString() + "?" + params.join("&"));
+  return QUrl::fromEncoded(QString("%1?%2").arg(url.toString()).arg(params.join("&")).toAscii());
 }
 
 bool Item::doProcessSearchResult(const QByteArray &response, int &newPagesCount)
@@ -190,7 +186,7 @@ bool Item::doProcessSearchResult(const QByteArray &response, int &newPagesCount)
   return (!respError && _photoUrl.isValid() && !_lastPhotoUrls.contains(_photoUrl));
 }
 
-QUrl Item::prepareSizeRequest(QHttpRequestHeader & /* header */)
+QUrl Item::prepareSizeRequest(HttpEngine::Operation & /* op */)
 {
   return QUrl("/");
 }
@@ -200,12 +196,12 @@ QSize Item::doProcessSizeRequestResult(const QByteArray & /* response */)
   return QApplication::desktop()->screenGeometry().size();
 }
 
-QUrl Item::prepareDownload(QHttpRequestHeader & /* header */)
+QUrl Item::prepareDownload(HttpEngine::Operation & /* op */)
 {
   return _photoUrl;
 }
 
-QUrl Item::prepareInfoCollect(QHttpRequestHeader & /* header */)
+QUrl Item::prepareInfoCollect(HttpEngine::Operation & /* op */)
 {
   _lastPhotoUrls.insert(_photoUrl);
   return QUrl("/");
