@@ -27,9 +27,6 @@ TRANSLATOR Picasa::DialogWidget
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <QtCore>
-#include <QtGui>
-#include <QtNetwork>
 #include <QtXml>
 
 #include "httpengine.h"
@@ -57,7 +54,7 @@ int Item::doCalculateNextIndex(bool randomMode, int currentIndex, int pages) con
   return (pages)? (currentIndex + ((randomMode)? (qrand() % 5) + 1 : 1)) % pages : 1;
 }
 
-QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
+QUrl Item::doPrepareInit(HttpEngine::Operation & /* op */)
 {
   _photoUrl.clear();
   _sourceUrl.clear();
@@ -69,7 +66,7 @@ QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
   return QUrl();
 }
 
-QUrl Item::doPrepareSearch(QHttpRequestHeader & /* header */, bool & /*shouldEncode */)
+QUrl Item::doPrepareSearch(HttpEngine::Operation & /* op */)
 {
   QUrl url("http://picasaweb.google.com/data/feed/base/all");
 
@@ -173,7 +170,7 @@ bool Item::doProcessSearchResult(const QByteArray &response, int &newPagesCount)
   return (_photoUrl.isValid() && !_lastPhotoUrls.contains(_photoUrl));
 }
 
-QUrl Item::prepareSizeRequest(QHttpRequestHeader & /* header */)
+QUrl Item::prepareSizeRequest(HttpEngine::Operation & /* op */)
 {
   return QUrl("/");
 }
@@ -183,12 +180,12 @@ QSize Item::doProcessSizeRequestResult(const QByteArray & /* response */)
   return photoSize;
 }
 
-QUrl Item::prepareDownload(QHttpRequestHeader & /* header */)
+QUrl Item::prepareDownload(HttpEngine::Operation & /* op */)
 {
   return _photoUrl;
 }
 
-QUrl Item::prepareInfoCollect(QHttpRequestHeader & /* header */)
+QUrl Item::prepareInfoCollect(HttpEngine::Operation & /* op */)
 {
   _lastPhotoUrls.insert(_photoUrl);
   return QUrl("/");
