@@ -17,14 +17,149 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <QtCore>
-#include <QtGui>
-#include <QtNetwork>
-
 #include "gui.h"
 #include "defs.h"
 #include "engine.h"
 #include "settings.h"
+#include "wally.h"
+
+static QString positionToString(Wally::Application::Position position)
+{
+  switch (position)
+  {
+    case Wally::Application::Centered:
+      return QObject::tr("Centered");
+
+    case Wally::Application::Tiled:
+      return QObject::tr("Tiled");
+
+    case Wally::Application::CenterTiled:
+      return QObject::tr("Center Tiled");
+
+    case Wally::Application::CenteredMaxpect:
+      return QObject::tr("Centered Maxpect");
+
+    case Wally::Application::TiledMaxpect:
+      return QObject::tr("Tiled Maxpect");
+
+    case Wally::Application::Scaled:
+      return QObject::tr("Scaled");
+
+    case Wally::Application::CenteredAutoFit:
+      return QObject::tr("Centered Auto Fit");
+
+    case Wally::Application::ScaleAndCrop:
+      return QObject::tr("Scale & Crop");
+
+    case Wally::Application::SymmetricalTiled:
+      return QObject::tr("Symmetrical Tiled");
+
+    case Wally::Application::MirroredTiled:
+      return QObject::tr("Mirrored Tiled");
+
+    case Wally::Application::SymmetricalMirroredTiled:
+      return QObject::tr("Symmetrical Mirrored Tiled");
+
+    default:
+      return QString();
+  }
+}
+
+int PositionModel::rowCount(const QModelIndex & /* parent */) const
+{
+  return static_cast< int > (Wally::Application::SymmetricalMirroredTiled) + 1;
+}
+
+QVariant PositionModel::data(const QModelIndex &index, int role) const
+{
+  if (!index.isValid() || (role != Qt::DisplayRole))
+    return QVariant();
+
+  switch (index.column())
+  {
+    case 0:
+      return positionToString(static_cast<Wally::Application::Position> (index.row()));
+      break;
+
+    case 1:
+      switch (static_cast<Wally::Application::Position> (index.row()))
+      {
+        case Wally::Application::Centered:
+          return ":/images/centered";
+
+        case Wally::Application::Tiled:
+          return ":/images/tiled";
+
+        case Wally::Application::CenterTiled:
+          return ":/images/center_tiled";
+
+        case Wally::Application::CenteredMaxpect:
+          return ":/images/centered_maxpect";
+
+        case Wally::Application::TiledMaxpect:
+          return ":/images/tiled_maxpect";
+
+        case Wally::Application::Scaled:
+          return ":/images/scaled";
+
+        case Wally::Application::CenteredAutoFit:
+          return ":/images/centered_autofit";
+
+        case Wally::Application::ScaleAndCrop:
+          return ":/images/scale_crop";
+
+        case Wally::Application::SymmetricalTiled:
+          return ":/images/symmetrical_tiled";
+
+        case Wally::Application::MirroredTiled:
+          return ":/images/mirrored_tiled";
+
+        case Wally::Application::SymmetricalMirroredTiled:
+          return ":/images/symmetrical_mirrored_tiled";
+      }
+  }
+
+  return QVariant();
+}
+
+QVariant PositionModel::headerData(int section, Qt::Orientation orientation, int role) const
+{
+  if ((orientation == Qt::Vertical) || (role != Qt::DisplayRole))
+    return QVariant();
+
+  switch (section)
+  {
+    case 0:
+      return tr("Position");
+
+    case 1:
+      return tr("Picture smaller than screen on the left, greater than screen on the right");
+  }
+
+  return QVariant();
+}
+
+void PositionDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
+{
+  QPixmap pixmap(index.data().toString());
+
+  painter->setRenderHint(QPainter::Antialiasing,true);
+  painter->fillRect(option.rect,(option.state & QStyle::State_Selected)? _palette.brush(QPalette::Highlight) :
+                                                                         _palette.brush(QPalette::Base));
+  painter->drawPixmap(option.rect.topLeft() + QPoint(2,2),pixmap);
+}
+
+QSize PositionDelegate::sizeHint(const QStyleOptionViewItem & /* option */, const QModelIndex & /* index */) const
+{
+  return QImageReader(":/images/centered_maxpect").size() + QSize(5,5);
+}
+
+void PositionLabelDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
+{
+  QStyleOptionViewItem itemOption(option);
+  itemOption.state = itemOption.state & ~QStyle::State_HasFocus;
+  QItemDelegate::paint(painter,itemOption,index);
+}
 
 SettingsDialog::SettingsDialog(QWidget *parent) : Gui::Dialog(Gui::Dialog::CenterOfScreen,parent)
 {
@@ -118,7 +253,16 @@ SettingsDialog::SettingsDialog(QWidget *parent) : Gui::Dialog(Gui::Dialog::Cente
   cbAutoLaunchOnSysStart->setEnabled(true);
   cbViewInfoInTooltip->setEnabled(false);
   cbViewInfoInTooltip->setChecked(false);
-#else
+#endif
+
+#ifdef Q_WS_MAC
+  cbAutoLaunchOnSysStart->setEnabled(false);
+  cbAutoLaunchOnSysStart->setChecked(false);
+  cbViewInfoInTooltip->setEnabled(false);
+  cbViewInfoInTooltip->setChecked(false);
+#endif
+
+#ifdef Q_WS_X11
   cbAutoLaunchOnSysStart->setEnabled(false);
   cbAutoLaunchOnSysStart->setChecked(false);
 #endif
@@ -126,7 +270,6 @@ SettingsDialog::SettingsDialog(QWidget *parent) : Gui::Dialog(Gui::Dialog::Cente
   connect(cbIntervalUnit,SIGNAL(currentIndexChanged(int)),this,SLOT(settingsModified()));
   connect(cbIntervalUnit,SIGNAL(currentIndexChanged(int)),this,SLOT(changeInterval()));
   connect(sbInterval,SIGNAL(valueChanged(int)),this,SLOT(settingsModified()));
-  connect(cbPosition,SIGNAL(currentIndexChanged(int)),this,SLOT(settingsModified()));
   connect(rbDirectConnection,SIGNAL(toggled(bool)),this,SLOT(settingsModified()));
   connect(rbProxyConnection,SIGNAL(toggled(bool)),this,SLOT(settingsModified()));
   connect(leProxyPassword,SIGNAL(textChanged(const QString &)),this,SLOT(settingsModified()));
@@ -139,6 +282,8 @@ SettingsDialog::SettingsDialog(QWidget *parent) : Gui::Dialog(Gui::Dialog::Cente
   connect(cbOnlyLandscapes,SIGNAL(toggled(bool)),this,SLOT(settingsModified()));
   connect(cbRandomOrder,SIGNAL(toggled(bool)),this,SLOT(settingsModified()));
   connect(cbSwitchOnPlay,SIGNAL(toggled(bool)),this,SLOT(settingsModified()));
+  connect(cbDisableSplashScreen,SIGNAL(toggled(bool)),this,SLOT(settingsModified()));
+  connect(cbQuitAfterBackgroundChange,SIGNAL(toggled(bool)),this,SLOT(settingsModified()));
   connect(cbUseFullDesktop,SIGNAL(toggled(bool)),this,SLOT(settingsModified()));
   connect(cbViewInfoInTooltip,SIGNAL(toggled(bool)),this,SLOT(settingsModified()));
   connect(cbViewInfoOnPhoto,SIGNAL(toggled(bool)),this,SLOT(settingsModified()));
@@ -198,7 +343,8 @@ void SettingsDialog::loadSettings(const WallySettings &mainSettings)
   sbInterval->setValue(_settings.value(MAIN_SECTION).value(INTERVAL).toInt());
   cbIntervalUnit->setCurrentIndex(cbIntervalUnit->findData(_settings.value(MAIN_SECTION).value(INTERVAL_UNIT)));
   pbBorderColor->setColor(borderColor);
-  cbPosition->setCurrentIndex(_settings.value(MAIN_SECTION).value(WALLPAPER_POSITION).toInt());
+  pbPosition->setProperty("wallPosition",_settings.value(MAIN_SECTION).value(WALLPAPER_POSITION));
+  pbPosition->setText(positionToString(static_cast<Wally::Application::Position> (_settings.value(MAIN_SECTION).value(WALLPAPER_POSITION).toInt())).replace("&","&&"));
   cbSwitchOnPlay->setChecked(_settings.value(MAIN_SECTION).value(SWITCH_ON_PLAY).toBool());
   cbAutoPlay->setChecked(_settings.value(MAIN_SECTION).value(PLAY_ON_START).toBool());
   cbAutoLaunchOnSysStart->setChecked(_settings.value(MAIN_SECTION).value(RUN_ON_SYS_START).toBool());
@@ -206,6 +352,8 @@ void SettingsDialog::loadSettings(const WallySettings &mainSettings)
   cbRotateImages->setChecked(_settings.value(MAIN_SECTION).value(EXIF_ROTATE_IMAGES).toBool());
   cbSizeConstraint->setCurrentIndex(_settings.value(MAIN_SECTION).value(SIZE_CONSTRAINT).toInt());
   cbViewInfoInTooltip->setChecked(_settings.value(MAIN_SECTION).value(VIEW_INFO_IN_TOOLTIP).toBool());
+  cbDisableSplashScreen->setChecked(_settings.value(MAIN_SECTION).value(DISABLE_SPLASH_SCREEN).toBool());
+  cbQuitAfterBackgroundChange->setChecked(_settings.value(MAIN_SECTION).value(QUIT_AFTER_BACKGROUND_CHANGE).toBool());
   cbRandomOrder->setChecked(_settings.value(MAIN_SECTION).value(RANDOM_SEARCH).toBool());
   cbUseFullDesktop->setChecked(_settings.value(MAIN_SECTION).value(USE_FULL_DESKTOP_AREA).toBool());
   cbViewInfoOnPhoto->setChecked(_settings.value(MAIN_SECTION).value(VIEW_INFO_ON_PHOTO).toBool());
@@ -233,11 +381,14 @@ WallySettings SettingsDialog::settings()
 {
   WallySettings newSettings;
 
+  newSettings[MAIN_SECTION][DISABLE_SPLASH_SCREEN] = cbDisableSplashScreen->isChecked();
+  newSettings[MAIN_SECTION][QUIT_AFTER_BACKGROUND_CHANGE] = cbQuitAfterBackgroundChange->isChecked();
+  newSettings[MAIN_SECTION][INTERVAL] = sbInterval->value();
   newSettings[MAIN_SECTION][INTERVAL] = sbInterval->value();
   newSettings[MAIN_SECTION][INTERVAL_UNIT] = cbIntervalUnit->itemData(cbIntervalUnit->currentIndex()).toInt();
   newSettings[MAIN_SECTION][BORDER_COLOR] = pbBorderColor->color().name();
   newSettings[MAIN_SECTION][AUTO_COLOR] = !pbBorderColor->color().alpha();
-  newSettings[MAIN_SECTION][WALLPAPER_POSITION] = cbPosition->currentIndex();
+  newSettings[MAIN_SECTION][WALLPAPER_POSITION] = static_cast<Wally::Application::Position> (pbPosition->property("wallPosition").toInt());
   newSettings[MAIN_SECTION][SWITCH_ON_PLAY] = cbSwitchOnPlay->isChecked();
   newSettings[MAIN_SECTION][PLAY_ON_START] = cbAutoPlay->isChecked();
   newSettings[MAIN_SECTION][RUN_ON_SYS_START] = cbAutoLaunchOnSysStart->isChecked();
@@ -292,6 +443,51 @@ void SettingsDialog::showEvent(QShowEvent *event)
   Gui::Dialog::showEvent(event);
 }
 
+void SettingsDialog::on_pbPosition_clicked()
+{
+  QScopedPointer< Gui::Dialog > dialog(new Gui::Dialog(Gui::Dialog::CenterOfScreen,this));
+  PositionModel *model = new PositionModel(dialog.data());
+  QTableView *view = new QTableView(dialog.data());
+  QItemSelectionModel *selectionModel = new QItemSelectionModel(model,dialog.data());
+
+  dialog->setWindowTitle(tr("Set position"));
+
+  QVBoxLayout *layout = new QVBoxLayout;
+  QDialogButtonBox *dialogButtons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel,
+                                                         Qt::Horizontal,dialog.data());
+  connect(dialogButtons,SIGNAL(accepted()),dialog.data(),SLOT(accept()));
+  connect(dialogButtons,SIGNAL(rejected()),dialog.data(),SLOT(reject()));
+
+  view->setModel(model);
+  view->setItemDelegateForColumn(0,new PositionLabelDelegate);
+  view->setItemDelegateForColumn(1,new PositionDelegate(QApplication::palette()));
+  view->setSelectionBehavior(QAbstractItemView::SelectRows);
+  view->setSelectionMode(QAbstractItemView::SingleSelection);
+  view->setSelectionModel(selectionModel);
+  view->verticalHeader()->setVisible(false);
+  view->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
+  view->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);
+  view->setEditTriggers(QAbstractItemView::NoEditTriggers);
+
+  layout->addWidget(view);
+  layout->addWidget(dialogButtons);
+  dialog->setLayout(layout);
+  dialog->resize(700,500);
+  connect(dialog.data(),SIGNAL(executed()),view,SLOT(resizeColumnsToContents()));
+  connect(dialog.data(),SIGNAL(executed()),view,SLOT(resizeRowsToContents()));
+
+  selectionModel->select(model->index(pbPosition->property("wallPosition").toInt(),0),
+                         QItemSelectionModel::SelectCurrent | QItemSelectionModel::Rows);
+  view->scrollTo(model->index(pbPosition->property("wallPosition").toInt(),0));
+  if (dialog->exec() == QDialog::Accepted)
+  {
+    Wally::Application::Position p = static_cast<Wally::Application::Position> (selectionModel->currentIndex().row());
+    pbPosition->setProperty("wallPosition",static_cast<int> (p));
+    pbPosition->setText(positionToString(p).replace("&","&&"));
+    settingsModified();
+  }
+}
+
 void SettingsDialog::on_rbProxyConnection_toggled(bool checked)
 {
   wdgProxy->setEnabled(checked);
