@@ -27,9 +27,6 @@ TRANSLATOR SmugMug::DialogWidget
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <QtCore>
-#include <QtGui>
-#include <QtNetwork>
 #include <QtXml>
 
 #include "httpengine.h"
@@ -57,7 +54,7 @@ int Item::doCalculateNextIndex(bool randomMode, int currentIndex, int /* pages *
   return currentIndex + ((randomMode)? (qrand() % 5) + 1 : 1);
 }
 
-QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
+QUrl Item::doPrepareInit(HttpEngine::Operation & /* op */)
 {
   _photoUrl.clear();
   _sourceUrl.clear();
@@ -68,7 +65,7 @@ QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
   return QUrl();
 }
 
-QUrl Item::doPrepareSearch(QHttpRequestHeader & /* header */, bool & /* shouldEncode */)
+QUrl Item::doPrepareSearch(HttpEngine::Operation & /* op */)
 {
   QUrl url("http://api.smugmug.com/hack/feed.mg");
 
@@ -169,7 +166,7 @@ bool Item::doProcessSearchResult(const QByteArray &response, int & /* newPagesCo
   return (_photoUrl.isValid() && !_lastPhotoUrls.contains(_photoUrl));
 }
 
-QUrl Item::prepareSizeRequest(QHttpRequestHeader & /* header */)
+QUrl Item::prepareSizeRequest(HttpEngine::Operation & /* op */)
 {
   return QUrl("/");
 }
@@ -179,12 +176,12 @@ QSize Item::doProcessSizeRequestResult(const QByteArray & /* response */)
   return photoSize;
 }
 
-QUrl Item::prepareDownload(QHttpRequestHeader & /* header */)
+QUrl Item::prepareDownload(HttpEngine::Operation & /* op */)
 {
   return _photoUrl;
 }
 
-QUrl Item::prepareInfoCollect(QHttpRequestHeader & /* header */)
+QUrl Item::prepareInfoCollect(HttpEngine::Operation & /* op */)
 {
   _lastPhotoUrls.insert(_photoUrl);
   return QUrl("/");
