@@ -27,10 +27,7 @@ TRANSLATOR Yahoo::DialogWidget
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <QtCore>
-#include <QtGui>
 #include <QtXml>
-#include <QtNetwork>
 
 #include "httpengine.h"
 #include "yahoo.h"
@@ -72,7 +69,7 @@ int Item::doCalculateNextIndex(bool randomMode, int currentIndex, int pages) con
   return (pages)? (currentIndex + ((randomMode)? (qrand() % 5) + 1 : 1) % pages) : 1;
 }
 
-QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
+QUrl Item::doPrepareInit(HttpEngine::Operation & /* op */)
 {
   photoTitle.clear();
   photoDescription.clear();
@@ -84,7 +81,7 @@ QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
   return QUrl();
 }
 
-QUrl Item::doPrepareSearch(QHttpRequestHeader & /* header */, bool & /* shouldEncode */)
+QUrl Item::doPrepareSearch(HttpEngine::Operation & /* op */)
 {
   QUrl url("http://search.yahooapis.com/ImageSearchService/V1/imageSearch");
 
@@ -179,7 +176,7 @@ bool Item::doProcessSearchResult(const QByteArray &response, int &newPagesCount)
   return (!respError && _photoUrl.isValid() && !_lastPhotoUrls.contains(_photoUrl));
 }
 
-QUrl Item::prepareSizeRequest(QHttpRequestHeader & /* header */)
+QUrl Item::prepareSizeRequest(HttpEngine::Operation & /* op */)
 {
   return QUrl("/");
 }
@@ -189,12 +186,12 @@ QSize Item::doProcessSizeRequestResult(const QByteArray & /* response */)
   return photoSize;
 }
 
-QUrl Item::prepareDownload(QHttpRequestHeader & /* header */)
+QUrl Item::prepareDownload(HttpEngine::Operation & /* op */)
 {
   return _photoUrl;
 }
 
-QUrl Item::prepareInfoCollect(QHttpRequestHeader & /* header */)
+QUrl Item::prepareInfoCollect(HttpEngine::Operation & /* op */)
 {
   _lastPhotoUrls.insert(_photoUrl);
   return QUrl("/");
